package org.jeecg.modules.xcx.shop.service;

import org.jeecg.common.api.vo.Result;
import org.jeecg.modules.xcx.shop.req.*;

public interface IShopService {

    /**
     * 申请店铺
     * @param applyShopReq
     * @return
     */
    Result<?> applyShop(ApplyShopReq applyShopReq);

    /**
     * 申请提现
     * @param applyWithdrawalReq
     * @return
     */
    Result<?> applyWithdrawal(ApplyWithdrawalReq applyWithdrawalReq);

    /**
     * 提现日志
     * @param withdrawalPageReq
     * @return
     */
    Result<?> withdrawalPage(WithdrawalPageReq withdrawalPageReq);


    /**
     * 我的用户
     * @param myUserReq
     * @return
     */
    Result<?> myUser(MyUserReq myUserReq);

    /**
     * 水洗店首页
     * @param token
     * @return
     */
    Result<?> shopIndex(String token);

    /**
     * 获取绑定的店铺信息
     * @param token
     * @return
     */
    Result<?> getShop(String token);

    /**
     * 修改店铺营业时间
     * @param editShopJobTimeReq
     * @return
     */
    Result<?> editShopJobTime(EditShopJobTimeReq editShopJobTimeReq);

    /**
     * 绑定微信
     * @param bindWxReq
     * @return
     */
    Result<?> bindWx(BindWxReq bindWxReq);


    /**
     * 修改店铺信息
     * @param editShopInfoReq
     * @return
     */
    Result<?> editShopInfo(EditShopInfoReq editShopInfoReq);


}
